pub fn request_battery_optimization_exemption<R: Runtime>(
app: AppHandle<R>,
) -> Result<(), Error>Expand description
Request exemption from battery optimization.
This will show a system dialog asking the user to allow the app to run without battery optimization restrictions.